#include "precomp.h"
#include "shell-icon-provider.h"
#include "qml_helper.h"

int LookUp(PCSTR pszArg)
{
    int nSize = 0;

    if(pszArg == nullptr) return 0;

    // The possbile sizes for the image that is requested
    struct
    {
        PCSTR pszSize;
        int nSize;
    } const sizeTable[] = { {"small", 16}, {"medium", 48}, {"large", 96}, {"extralarge", 256} };

    for (int i = 0; i < ARRAYSIZE(sizeTable); i++)
    {
        if(_stricmp(sizeTable[i].pszSize, pszArg) == 0)
        {
            nSize = sizeTable[i].nSize;
            break;
        }
    }

    return nSize;
}

void DisplayUsage(const char *a0)
{
    printf("Usage:\n");
    printf("%s <size> <Absolute Path to file>\n", a0);
    printf("size - small, medium, large, extralarge\n");
    printf("e.g. ImageFactorySample.exe medium c:\\HelloWorld.jpg \n");
}

int main(int argc, char *argv[])
{
    int nSize = LookUp(argv[1]);
    if (!nSize)     {
        DisplayUsage(argv[0]);
        return 0;
    }

    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
    QGuiApplication app(argc, argv);

    QQmlApplicationEngine engine;

    // register shell icon provider
    engine.addImageProvider(ShellIconProvider::getPrefix(), new ShellIconProvider);

    // register singleton object
    qmlRegisterSingletonType<QmlHelper>("NgExplorer.QmlGlobal", 1, 0, "QmlHelper", QmlHelper::qmlGetInstance);
    engine.rootContext()->setContextProperty("testImageSize", QVariant(nSize));
    engine.rootContext()->setContextProperty("testImageSource", QVariant(argv[2]));

    engine.load(QUrl(QLatin1String("qrc:/main.qml")));
    if (engine.rootObjects().isEmpty())
        return -1;




    return app.exec();
}
