#ifndef _SCOPE_GUARD_H_
#define _SCOPE_GUARD_H_

#include <functional>

class ScopeGuard
{
public:
    explicit ScopeGuard(std::function<void()> fn)
        :exitFn(fn),dismissed(false){}

    ~ScopeGuard() { if(!dismissed) exitFn(); }

    void dismiss() { dismissed = true; }

private:
    std::function<void()>   exitFn;
    bool                    dismissed;

private:
    // not-copyable
    ScopeGuard(ScopeGuard const&);
    ScopeGuard& operator=(ScopeGuard const&);
};

#define SCOPEGUARD_LINENAME_CAT(name, line) name ## line
#define SCOPEGUARD_NAME_BY_LINE(name,line) SCOPEGUARD_LINENAME_CAT(name, line)
#define ON_SCOPE_EXIT(callback) ScopeGuard SCOPEGUARD_NAME_BY_LINE(EXIT,__LINE__)(callback)

#endif